@@ -2,15 +2,15 @@ from bs4 import BeautifulSoup
 from requests import Session
 
 
-def get_page_soup(session: Session, url: str):
-    page = session.get(url)
-    return BeautifulSoup(page.content, features="lxml")
-
-
 def get_page_soup(page_content: str):
     return BeautifulSoup(page_content, features="lxml")
 
 
+def get_page_soup_by_sessions(session: Session, url: str):
+    page = session.get(url)
+    return BeautifulSoup(page.content, features="lxml")
+
+
 def attribute_value_for_all_elements(soup: BeautifulSoup, selector: str, attribute: str):
     elements = soup.select(selector)
     return [e.get(attribute) for e in elements if e.get(attribute, '') != '']
